<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color</source>
        <translation>Rengi değiştirmek için tıklayın</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>Renk Seç</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="178"/>
        <source>GTK themes</source>
        <translation>GTK temaları</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="179"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; üzerine yazıldı.&lt;/p&gt;&lt;p&gt;&apos;%2&apos; dizininde eski ayarlarınızın bir kopyasını bulabilirsiniz.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error: gsettings cannot be run</source>
        <translation>Hata: gsettings çalıştırılamıyor</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>Yazı tipi</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>Kullanıcı arayüzü öntanımlı yazıtipi</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>Yazı tipi adı:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>Biçem:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="77"/>
        <source>Point size:</source>
        <translation>Yazıtipi boyutu:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="54"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="59"/>
        <source>Bold</source>
        <translation>Kalın</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="64"/>
        <source>Italic</source>
        <translation>Eğik</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="69"/>
        <source>Bold Italic</source>
        <translation>Kalın eğik</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>Aşağıdaki ayarlar yalnızca yeni başlatılan uygulamaları etkiler</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>Yazıtipi yumuşatması kullan</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="153"/>
        <source>Font hinting style:</source>
        <translation>Yazıtipi ipucu biçemi:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="211"/>
        <source>Monospace:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="164"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="169"/>
        <source>Slight</source>
        <translation>Hafif</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="174"/>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="179"/>
        <source>Full</source>
        <translation>Tam</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="146"/>
        <source>Font hinting</source>
        <translation>Yazı tipi ipucu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="187"/>
        <source>Resolution (DPI):</source>
        <translation>Çözünürlük (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="204"/>
        <source>Autohint</source>
        <translation>Otomatik ipucu</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Subpixel antialiasing:</source>
        <translation>Alt-piksel yumuşatma:</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="138"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="56"/>
        <source>GTK Style</source>
        <translation>GTK Biçemi</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="75"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>GTK temalarını ayarla (GTK yapılandırma dosyaları üzerine yazılacak!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="105"/>
        <source>GTK 3 Theme:</source>
        <translation>GTK 3 Teması:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="89"/>
        <source>GTK 2 Theme:</source>
        <translation>GTK 2 Teması:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="117"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>Tekdüzen temalı girişimleri denemek için, ya tüm listelerde benzer stil / temayı (varsa) seçin ya da GTK temalarını taklit etmek için &apos;gtk2&apos; Qt stilini (varsa) seçin.

GTK uygulamalarının temaları anında uygulamasına yardımcı olmak için &apos;xsettingsd&apos; &apos;nin kurulu olduğundan emin olun.</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Görünüm Ayarları</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>Simge Teması</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation>XDG simge temasının KDE eklentisi -&gt; Aşağıdaki Renk Şeması</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation>Simgeleri gereç biçemine (palet) göre renklendir</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>LXQt Teması</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation>Tema tarafından sağlanan duvar kağıdını kullan</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="64"/>
        <source>Use palette provided by theme</source>
        <translation>Tema tarafından sağlanan paleti kullan</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="83"/>
        <source>(User Theme)</source>
        <translation>(Kullanıcı Teması)</translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="188"/>
        <source>Open theme folder</source>
        <translation>Tema dizinini aç</translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation>Paletler</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation>Süzgeç...</translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation>&amp;Kaldır</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt Görünüm Yapılandırma</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Widget Style</source>
        <translation>Gereç Biçemi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Icons Theme</source>
        <translation>Simge Teması</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>LXQt Theme</source>
        <translation>LXQt Teması</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Font</source>
        <translation>Yazıtipi</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>Cursor</source>
        <translation>İmleç</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>GTK Style</source>
        <translation>GTK Biçemi</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="45"/>
        <source>Widget Style</source>
        <translation>Gereç Biçemi</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="75"/>
        <source>Qt Palette</source>
        <translation>Qt Paleti</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="89"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation>Bazı Qt biçemleri bu renkleri görmezden gelebilir.</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="114"/>
        <source>Window:</source>
        <translation>Pencere:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="124"/>
        <source>View:</source>
        <translation>Görünüm:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="134"/>
        <source>Selection:</source>
        <translation>Seçim:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="144"/>
        <source>Tooltip:</source>
        <translation>İpucu:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="158"/>
        <source>Link:</source>
        <translation>Bağlantı:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="178"/>
        <source>Window Text:</source>
        <translation>Pencere Metni:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="188"/>
        <source>View Text:</source>
        <translation>Metni Görüntüle:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="198"/>
        <source>Selected Text:</source>
        <translation>Seçilen Metin:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="208"/>
        <source>Tooltip Text:</source>
        <translation>İpucu Metni:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="222"/>
        <source>Visited Link:</source>
        <translation>Ziyaret Edilen Bağlantı:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="254"/>
        <source>&amp;Save Palette</source>
        <translation>Paleti &amp;Kaydet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="261"/>
        <source>&amp;Load Palette</source>
        <translation>Paleti &amp;Yükle</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="281"/>
        <source>&amp;Default Palette</source>
        <translation>&amp;Varsayılan Palet</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="296"/>
        <location filename="../styleconfig.ui" line="306"/>
        <location filename="../styleconfig.ui" line="338"/>
        <location filename="../styleconfig.ui" line="348"/>
        <location filename="../styleconfig.ui" line="380"/>
        <source>May be overridden by Qt style or app</source>
        <translation>Qt biçemi veya uygulaması tarafından geçersiz kılınabilir</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="299"/>
        <source>Toolbar button style:</source>
        <translation>Araç çubuğu düğme stili:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="310"/>
        <source>Only display the icon</source>
        <translation>Sadece simgeyi göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="315"/>
        <source>Only display the text</source>
        <translation>Sadece metni göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="320"/>
        <source>The text appears beside the icon</source>
        <translation>Simgenin yanında metin göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="325"/>
        <source>The text appears under the icon</source>
        <translation>Simge altında metin göster</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="330"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="341"/>
        <source>Toolbar icon size:</source>
        <translation>Araç çubuğu simge boyutu:</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="352"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="357"/>
        <source>22</source>
        <translation>22</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="362"/>
        <source>24</source>
        <translation>24</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="367"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="372"/>
        <source>48</source>
        <translation>48</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="383"/>
        <source>Activate item on single click</source>
        <translation>Tek tıklamayla öğeyi etkinleştir</translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Style:</source>
        <translation>Qt Biçemi:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <location filename="../styleconfig.cpp" line="340"/>
        <source>Save Palette</source>
        <translation>Paleti Kaydet</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <source>Palette name:</source>
        <translation>Palet adı:</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="341"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation>Aynı ada sahip bir palet var.
Değiştirmek istiyor musun?</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="484"/>
        <source>Remove Palettes</source>
        <translation>Paletleri Kaldır</translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="485"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation>Seçilen paleti/paletleri gerçekten kaldırmak istiyor musunuz?
Kök paletler, varsa bozulmadan kalacaktır.</translation>
    </message>
</context>
</TS>
